@@ -23,10 +23,9 @@
 
 #include "simonsolver.h"
 
+#include "../kpat_debug.h"
 #include "../simon.h"
 
-#include <QDebug>
-
 const int CHUNKSIZE = 100;
 const long int MAX_ITERS_LIMIT = 200000;
 
@@ -38,7 +37,7 @@ const long int MAX_ITERS_LIMIT = 200000;
 void SimonSolver::make_move(MOVE *m)
 {
 #if PRINT
-    //qDebug() << "\n\nmake_move\n";
+    //qCDebug(KPAT_LOG) << "\n\nmake_move\n";
     if ( m->totype == O_Type )
         fprintf( stderr, "move %d from %d out (at %d) Prio: %d\n\n", m->card_index, m->from, m->turn_index, m->pri );
     else
@@ -92,7 +91,7 @@ void SimonSolver::make_move(MOVE *m)
 void SimonSolver::undo_move(MOVE *m)
 {
 #if PRINT
-    //qDebug() << "\n\nundo_move\n";
+    //qCDebug(KPAT_LOG) << "\n\nundo_move\n";
     if ( m->totype == O_Type )
         fprintf( stderr, "move %d from %d out (at %d)\n\n", m->card_index, m->from, m->turn_index );
     else
