@@ -52,9 +52,9 @@ public:
     void setScene( QGraphicsScene * scene );
 
 protected:
-    virtual void resizeEvent( QResizeEvent * e );
-    virtual void drawBackground( QPainter * painter, const QRectF & rect );
-    virtual void receivePixmap( const QPixmap & pixmap );
+    void resizeEvent( QResizeEvent * e ) Q_DECL_OVERRIDE;
+    void drawBackground( QPainter * painter, const QRectF & rect ) Q_DECL_OVERRIDE;
+    void receivePixmap( const QPixmap & pixmap ) Q_DECL_OVERRIDE;
 
 private:
     void updateSceneSize();
